@@ -447,7 +447,7 @@ def binom_var_test_df(c1, c2, sym=False, max_m=-1, singleton=True) :
 
     return df_hist
 
-def binom_var_test(c1, c2, sym=False, max_m=-1) :
+def binom_var_test(c1, c2, sym=False, max_m=-1, singleton=True) :
     """ Binmial variance test along stripes
     Args:
     ----
@@ -455,7 +455,7 @@ def binom_var_test(c1, c2, sym=False, max_m=-1) :
     sym : flag indicates wether the size of both sample is assumed
           identical, hence p=1/2
     """
-    df_hist = binom_var_test_df(c1, c2, sym=sym, max_m=max_m)
+    df_hist = binom_var_test_df(c1, c2, sym=sym, max_m=max_m, singleton=singleton)
     return df_hist.groupby('m').pval.mean()
 
 def two_sample_pvals(c1, c2, randomize=False,
